All of lore.kernel.org
 help / color / mirror / Atom feed
From: Youling Tang <youling.tang@linux.dev>
To: Simon Horman <horms@verge.net.au>
Cc: kexec@lists.infradead.org, Huacai Chen <chenhuacai@kernel.org>,
	youling.tang@linux.dev, Youling Tang <tangyouling@kylinios.cn>
Subject: [PATCH 2/7] LoongArch: Fix comments
Date: Fri, 29 Aug 2025 17:10:35 +0800	[thread overview]
Message-ID: <20250829091040.35827-3-youling.tang@linux.dev> (raw)
In-Reply-To: <20250829091040.35827-1-youling.tang@linux.dev>

From: Youling Tang <tangyouling@kylinios.cn>

loongarch_load_other_segments() mainly loads initrd and cmdline. Fix this
annotation.

Signed-off-by: Youling Tang <tangyouling@kylinios.cn>
---
 kexec/arch/loongarch/kexec-pei-loongarch.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/kexec/arch/loongarch/kexec-pei-loongarch.c b/kexec/arch/loongarch/kexec-pei-loongarch.c
index 1a11103..f0e0d09 100644
--- a/kexec/arch/loongarch/kexec-pei-loongarch.c
+++ b/kexec/arch/loongarch/kexec-pei-loongarch.c
@@ -102,10 +102,10 @@ int pei_loongarch_load(int argc, char **argv, const char *buf,
 	/* Load the kernel */
 	add_segment(info, buf, len, kernel_segment, loongarch_mem.image_size);
 
 	/* Prepare and load dtb and initrd data */
 	result = loongarch_load_other_segments(info, hole_min);
 	if (result) {
-		fprintf(stderr, "kexec: Load dtb and initrd segments failed.\n");
+		fprintf(stderr, "kexec: Load initrd and cmdline segments failed.\n");
 		goto exit;
 	}
 
@@ -102,10 +102,10 @@ int pei_loongarch_load(int argc, char **argv, const char *buf,
 	add_segment(info, buf, len, kernel_segment, loongarch_mem.image_size);
 
-	/* Prepare and load dtb and initrd data */
+	/* Prepare and load initrd and cmdline data */
 	result = loongarch_load_other_segments(info, hole_min);
 	if (result) {
-- 
2.34.1



  parent reply	other threads:[~2025-08-29 10:20 UTC|newest]

Thread overview: 9+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2025-08-29  9:10 [PATCH 0/7] Fix and improve the LoongArch implementation Youling Tang
2025-08-29  9:10 ` [PATCH 1/7] kexec: Handle removal of multiple 'crashkernel' parameters Youling Tang
2025-08-29  9:10 ` Youling Tang [this message]
2025-08-29  9:10 ` [PATCH 3/7] LoongArch: Terminate the cmdline string using '\0' Youling Tang
2025-08-29  9:10 ` [PATCH 4/7] LoongArch: Enforce relocatable kernel check for crash dump Youling Tang
2025-08-29  9:10 ` [PATCH 5/7] LoongArch: Change initrd allocation to top-down Youling Tang
2025-08-29  9:10 ` [PATCH 6/7] LoongArch: Fix the use of loongarch_image_header in ELF format Youling Tang
2025-08-29  9:10 ` [PATCH 7/7] LoongArch: Add pe_hdr->machine check for pei format images Youling Tang
2025-08-29  9:19 ` [PATCH 0/7] Fix and improve the LoongArch implementation Youling Tang

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20250829091040.35827-3-youling.tang@linux.dev \
    --to=youling.tang@linux.dev \
    --cc=chenhuacai@kernel.org \
    --cc=horms@verge.net.au \
    --cc=kexec@lists.infradead.org \
    --cc=tangyouling@kylinios.cn \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.